Module lambda

Module lambda 

Structs

AddPermissionRequest
AddPermissionRequestBuilder
Use builder syntax to set the inputs and finish with build().
AddPermissionResponse
Cors
CorsBuilder
Use builder syntax to set the inputs and finish with build().
CreateEventSourceMappingRequest
Request to create an event source mapping
CreateEventSourceMappingRequestBuilder
Use builder syntax to set the inputs and finish with build().
CreateFunctionRequest
CreateFunctionRequestBuilder
Use builder syntax to set the inputs and finish with build().
CreateFunctionUrlConfigRequest
CreateFunctionUrlConfigRequestBuilder
Use builder syntax to set the inputs and finish with build().
CreateFunctionUrlConfigResponse
Environment
EnvironmentBuilder
Use builder syntax to set the inputs and finish with build().
EphemeralStorage
EphemeralStorageBuilder
Use builder syntax to set the inputs and finish with build().
EventSourceMapping
Represents an event source mapping
Filter
Individual filter in filter criteria
FilterBuilder
Use builder syntax to set the inputs and finish with build().
FilterCriteria
Filter criteria for event source mapping
FilterCriteriaBuilder
Use builder syntax to set the inputs and finish with build().
FunctionCode
FunctionCodeBuilder
Use builder syntax to set the inputs and finish with build().
FunctionConfiguration
FunctionUrlConfig
GetFunctionResponse
GetPolicyResponse
InvokeRequest
Request for invoking a Lambda function
InvokeRequestBuilder
Use builder syntax to set the inputs and finish with build().
InvokeResponse
Response from invoking a Lambda function
LambdaClient
ListEventSourceMappingsRequest
Request to list event source mappings
ListEventSourceMappingsRequestBuilder
Use builder syntax to set the inputs and finish with build().
ListEventSourceMappingsResponse
Response from listing event source mappings
ScalingConfig
Scaling configuration for SQS event source mapping
ScalingConfigBuilder
Use builder syntax to set the inputs and finish with build().
TracingConfig
TracingConfigBuilder
Use builder syntax to set the inputs and finish with build().
UpdateEventSourceMappingRequest
Request to update an event source mapping
UpdateEventSourceMappingRequestBuilder
Use builder syntax to set the inputs and finish with build().
UpdateFunctionCodeRequest
UpdateFunctionCodeRequestBuilder
Use builder syntax to set the inputs and finish with build().
UpdateFunctionConfigurationRequest
UpdateFunctionConfigurationRequestBuilder
Use builder syntax to set the inputs and finish with build().
VpcConfig
VPC configuration for Lambda function.
VpcConfigBuilder
Use builder syntax to set the inputs and finish with build().

Enums

InvocationType
Lambda invocation type

Traits

LambdaApi