CreateEventSourceMappingRequestBuilder

Struct CreateEventSourceMappingRequestBuilder 

pub struct CreateEventSourceMappingRequestBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> CreateEventSourceMappingRequestBuilder<S>

pub fn build(self) -> CreateEventSourceMappingRequest
where S: IsComplete,

Finish building and return the requested object

pub fn event_source_arn( self, value: String, ) -> CreateEventSourceMappingRequestBuilder<SetEventSourceArn<S>>
where S::EventSourceArn: IsUnset,

Required.

The Amazon Resource Name (ARN) of the event source (e.g., SQS queue)

pub fn function_name( self, value: String, ) -> CreateEventSourceMappingRequestBuilder<SetFunctionName<S>>
where S::FunctionName: IsUnset,

Required.

The name or ARN of the Lambda function

pub fn batch_size( self, value: i32, ) -> CreateEventSourceMappingRequestBuilder<SetBatchSize<S>>
where S::BatchSize: IsUnset,

Optional (Some / Option setters). The maximum number of records in each batch that Lambda pulls from your queue and sends to your function

pub fn maybe_batch_size( self, value: Option<i32>, ) -> CreateEventSourceMappingRequestBuilder<SetBatchSize<S>>
where S::BatchSize: IsUnset,

Optional (Some / Option setters). The maximum number of records in each batch that Lambda pulls from your queue and sends to your function

pub fn enabled( self, value: bool, ) -> CreateEventSourceMappingRequestBuilder<SetEnabled<S>>
where S::Enabled: IsUnset,

Optional (Some / Option setters). When true, the event source mapping is active. When false, Lambda pauses polling and invocation

pub fn maybe_enabled( self, value: Option<bool>, ) -> CreateEventSourceMappingRequestBuilder<SetEnabled<S>>
where S::Enabled: IsUnset,

Optional (Some / Option setters). When true, the event source mapping is active. When false, Lambda pauses polling and invocation

pub fn maximum_batching_window_in_seconds( self, value: i32, ) -> CreateEventSourceMappingRequestBuilder<SetMaximumBatchingWindowInSeconds<S>>
where S::MaximumBatchingWindowInSeconds: IsUnset,

Optional (Some / Option setters). The maximum amount of time, in seconds, that Lambda spends gathering records before invoking the function

pub fn maybe_maximum_batching_window_in_seconds( self, value: Option<i32>, ) -> CreateEventSourceMappingRequestBuilder<SetMaximumBatchingWindowInSeconds<S>>
where S::MaximumBatchingWindowInSeconds: IsUnset,

Optional (Some / Option setters). The maximum amount of time, in seconds, that Lambda spends gathering records before invoking the function

pub fn function_response_types( self, value: Vec<String>, ) -> CreateEventSourceMappingRequestBuilder<SetFunctionResponseTypes<S>>
where S::FunctionResponseTypes: IsUnset,

Optional (Some / Option setters). A list of current response type enums applied to the event source mapping

pub fn maybe_function_response_types( self, value: Option<Vec<String>>, ) -> CreateEventSourceMappingRequestBuilder<SetFunctionResponseTypes<S>>
where S::FunctionResponseTypes: IsUnset,

Optional (Some / Option setters). A list of current response type enums applied to the event source mapping

pub fn filter_criteria( self, value: FilterCriteria, ) -> CreateEventSourceMappingRequestBuilder<SetFilterCriteria<S>>
where S::FilterCriteria: IsUnset,

Optional (Some / Option setters). An object that defines the filter criteria that determine whether Lambda should process an event

pub fn maybe_filter_criteria( self, value: Option<FilterCriteria>, ) -> CreateEventSourceMappingRequestBuilder<SetFilterCriteria<S>>
where S::FilterCriteria: IsUnset,

Optional (Some / Option setters). An object that defines the filter criteria that determine whether Lambda should process an event

pub fn scaling_config( self, value: ScalingConfig, ) -> CreateEventSourceMappingRequestBuilder<SetScalingConfig<S>>
where S::ScalingConfig: IsUnset,

Optional (Some / Option setters). The maximum concurrency setting limits the number of concurrent instances of the function that an Amazon SQS event source can invoke

pub fn maybe_scaling_config( self, value: Option<ScalingConfig>, ) -> CreateEventSourceMappingRequestBuilder<SetScalingConfig<S>>
where S::ScalingConfig: IsUnset,

Optional (Some / Option setters). The maximum concurrency setting limits the number of concurrent instances of the function that an Amazon SQS event source can invoke