CreateFunctionRequestBuilder

Struct CreateFunctionRequestBuilder 

pub struct CreateFunctionRequestBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> CreateFunctionRequestBuilder<S>

pub fn build(self) -> CreateFunctionRequest
where S: IsComplete,

Finish building and return the requested object

pub fn function_name( self, value: String, ) -> CreateFunctionRequestBuilder<SetFunctionName<S>>
where S::FunctionName: IsUnset,

Required.

pub fn role(self, value: String) -> CreateFunctionRequestBuilder<SetRole<S>>
where S::Role: IsUnset,

Required.

pub fn code( self, value: FunctionCode, ) -> CreateFunctionRequestBuilder<SetCode<S>>
where S::Code: IsUnset,

Required.

pub fn package_type( self, value: String, ) -> CreateFunctionRequestBuilder<SetPackageType<S>>
where S::PackageType: IsUnset,

Optional (Some / Option setters). Default: "Image".to_string().

pub fn maybe_package_type( self, value: Option<String>, ) -> CreateFunctionRequestBuilder<SetPackageType<S>>
where S::PackageType: IsUnset,

Optional (Some / Option setters). Default: "Image".to_string().

pub fn description( self, value: String, ) -> CreateFunctionRequestBuilder<SetDescription<S>>
where S::Description: IsUnset,

Optional (Some / Option setters).

pub fn maybe_description( self, value: Option<String>, ) -> CreateFunctionRequestBuilder<SetDescription<S>>
where S::Description: IsUnset,

Optional (Some / Option setters).

pub fn timeout(self, value: i32) -> CreateFunctionRequestBuilder<SetTimeout<S>>
where S::Timeout: IsUnset,

Optional (Some / Option setters).

pub fn maybe_timeout( self, value: Option<i32>, ) -> CreateFunctionRequestBuilder<SetTimeout<S>>
where S::Timeout: IsUnset,

Optional (Some / Option setters).

pub fn memory_size( self, value: i32, ) -> CreateFunctionRequestBuilder<SetMemorySize<S>>
where S::MemorySize: IsUnset,

Optional (Some / Option setters).

pub fn maybe_memory_size( self, value: Option<i32>, ) -> CreateFunctionRequestBuilder<SetMemorySize<S>>
where S::MemorySize: IsUnset,

Optional (Some / Option setters).

pub fn publish(self, value: bool) -> CreateFunctionRequestBuilder<SetPublish<S>>
where S::Publish: IsUnset,

Optional (Some / Option setters).

pub fn maybe_publish( self, value: Option<bool>, ) -> CreateFunctionRequestBuilder<SetPublish<S>>
where S::Publish: IsUnset,

Optional (Some / Option setters).

pub fn environment( self, value: Environment, ) -> CreateFunctionRequestBuilder<SetEnvironment<S>>
where S::Environment: IsUnset,

Optional (Some / Option setters).

pub fn maybe_environment( self, value: Option<Environment>, ) -> CreateFunctionRequestBuilder<SetEnvironment<S>>
where S::Environment: IsUnset,

Optional (Some / Option setters).

pub fn architectures( self, value: Vec<String>, ) -> CreateFunctionRequestBuilder<SetArchitectures<S>>
where S::Architectures: IsUnset,

Optional (Some / Option setters).

pub fn maybe_architectures( self, value: Option<Vec<String>>, ) -> CreateFunctionRequestBuilder<SetArchitectures<S>>
where S::Architectures: IsUnset,

Optional (Some / Option setters).

pub fn tracing_config( self, value: TracingConfig, ) -> CreateFunctionRequestBuilder<SetTracingConfig<S>>
where S::TracingConfig: IsUnset,

Optional (Some / Option setters).

pub fn maybe_tracing_config( self, value: Option<TracingConfig>, ) -> CreateFunctionRequestBuilder<SetTracingConfig<S>>
where S::TracingConfig: IsUnset,

Optional (Some / Option setters).

pub fn tags( self, value: HashMap<String, String>, ) -> CreateFunctionRequestBuilder<SetTags<S>>
where S::Tags: IsUnset,

Optional (Some / Option setters).

pub fn maybe_tags( self, value: Option<HashMap<String, String>>, ) -> CreateFunctionRequestBuilder<SetTags<S>>
where S::Tags: IsUnset,

Optional (Some / Option setters).

pub fn ephemeral_storage( self, value: EphemeralStorage, ) -> CreateFunctionRequestBuilder<SetEphemeralStorage<S>>
where S::EphemeralStorage: IsUnset,

Optional (Some / Option setters).

pub fn maybe_ephemeral_storage( self, value: Option<EphemeralStorage>, ) -> CreateFunctionRequestBuilder<SetEphemeralStorage<S>>
where S::EphemeralStorage: IsUnset,

Optional (Some / Option setters).

pub fn kms_key_arn( self, value: String, ) -> CreateFunctionRequestBuilder<SetKmsKeyArn<S>>
where S::KmsKeyArn: IsUnset,

Optional (Some / Option setters).

pub fn maybe_kms_key_arn( self, value: Option<String>, ) -> CreateFunctionRequestBuilder<SetKmsKeyArn<S>>
where S::KmsKeyArn: IsUnset,

Optional (Some / Option setters).

pub fn vpc_config( self, value: VpcConfig, ) -> CreateFunctionRequestBuilder<SetVpcConfig<S>>
where S::VpcConfig: IsUnset,

Optional (Some / Option setters). VPC configuration for running the function inside a VPC

pub fn maybe_vpc_config( self, value: Option<VpcConfig>, ) -> CreateFunctionRequestBuilder<SetVpcConfig<S>>
where S::VpcConfig: IsUnset,

Optional (Some / Option setters). VPC configuration for running the function inside a VPC