pub struct InvokeRequest {
pub function_name: String,
pub invocation_type: InvocationType,
pub qualifier: Option<String>,
pub client_context: Option<String>,
pub log_type: Option<String>,
pub payload: Vec<u8>,
}Expand description
Request for invoking a Lambda function
Fields
function_name: StringThe name of the Lambda function
invocation_type: InvocationTypeThe invocation type
qualifier: Option<String>For versioned functions, the version to invoke
client_context: Option<String>Up to 3,583 bytes of base64-encoded data about the invoking client to pass to the function
log_type: Option<String>Set to Tail to include the execution log in the response
payload: Vec<u8>The JSON that you want to provide to your Lambda function as input
Implementations
Sourceimpl InvokeRequest
impl InvokeRequest
Sourcepub fn builder() -> InvokeRequestBuilder
pub fn builder() -> InvokeRequestBuilder
Create an instance of InvokeRequest using the builder syntax