UpdateEventSourceMappingRequest

Struct UpdateEventSourceMappingRequest 

pub struct UpdateEventSourceMappingRequest {
    pub batch_size: Option<i32>,
    pub enabled: Option<bool>,
    pub function_name: Option<String>,
    pub maximum_batching_window_in_seconds: Option<i32>,
    pub function_response_types: Option<Vec<String>>,
    pub filter_criteria: Option<FilterCriteria>,
    pub scaling_config: Option<ScalingConfig>,
}
Request to update an event source mapping

Fields

batch_size: Option<i32>

The maximum number of records in each batch that Lambda pulls from your queue and sends to your function

enabled: Option<bool>

When true, the event source mapping is active. When false, Lambda pauses polling and invocation

function_name: Option<String>

The name or ARN of the Lambda function

maximum_batching_window_in_seconds: Option<i32>

The maximum amount of time, in seconds, that Lambda spends gathering records before invoking the function

function_response_types: Option<Vec<String>>

A list of current response type enums applied to the event source mapping

filter_criteria: Option<FilterCriteria>

An object that defines the filter criteria that determine whether Lambda should process an event

scaling_config: Option<ScalingConfig>

The maximum concurrency setting limits the number of concurrent instances of the function that an Amazon SQS event source can invoke

Implementations