pub struct VpcConfig {
pub subnet_ids: Option<Vec<String>>,
pub security_group_ids: Option<Vec<String>>,
}Expand description
VPC configuration for Lambda function.
When configured, the Lambda function runs inside the specified VPC with access to the specified subnets and security groups.
Fields
subnet_ids: Option<Vec<String>>A list of VPC subnet IDs where the function will run. Lambda creates an elastic network interface for each subnet.
security_group_ids: Option<Vec<String>>A list of VPC security group IDs for the function’s network interfaces.
Implementations