pub struct AssumeRoleWithWebIdentityRequest {
pub role_arn: String,
pub role_session_name: String,
pub web_identity_token: String,
pub duration_seconds: Option<i32>,
pub policy: Option<String>,
pub policy_arns: Option<Vec<String>>,
pub provider_id: Option<String>,
}Fields
role_arn: StringThe ARN of the role to assume
role_session_name: StringAn identifier for the assumed role session
web_identity_token: StringThe OAuth 2.0 access token or OpenID Connect ID token
duration_seconds: Option<i32>The duration, in seconds, of the role session (900-43200)
policy: Option<String>An IAM policy in JSON format to use as an inline session policy
policy_arns: Option<Vec<String>>The Amazon Resource Names (ARNs) of IAM managed policies to use as managed session policies
provider_id: Option<String>The fully qualified host component of the domain name of the OAuth 2.0 identity provider
Implementations
Sourceimpl AssumeRoleWithWebIdentityRequest
impl AssumeRoleWithWebIdentityRequest
Sourcepub fn builder() -> AssumeRoleWithWebIdentityRequestBuilder
pub fn builder() -> AssumeRoleWithWebIdentityRequestBuilder
Create an instance of AssumeRoleWithWebIdentityRequest using the builder syntax