Structs
- Batch
Delete Builds Request - Batch
Delete Builds Request Builder - Use builder syntax to set the inputs and finish with
build(). - Batch
Delete Builds Response - Batch
GetBuilds Request - Batch
GetBuilds Request Builder - Use builder syntax to set the inputs and finish with
build(). - Batch
GetBuilds Response - Batch
GetProjects Request - Batch
GetProjects Request Builder - Use builder syntax to set the inputs and finish with
build(). - Batch
GetProjects Response - Build
- Build
Artifacts - Build
NotDeleted - Build
Phase - Cloud
Watch Logs Config - Cloud
Watch Logs Config Builder - Use builder syntax to set the inputs and finish with
build(). - Code
Build Client - Create
Project Request - Create
Project Request Builder - Use builder syntax to set the inputs and finish with
build(). - Create
Project Response - Delete
Project Request - Delete
Project Request Builder - Use builder syntax to set the inputs and finish with
build(). - Delete
Project Response - Environment
Variable - Environment
Variable Builder - Use builder syntax to set the inputs and finish with
build(). - Logs
Config - Logs
Config Builder - Use builder syntax to set the inputs and finish with
build(). - Logs
Location - Project
- Project
Artifacts - Project
Artifacts Builder - Use builder syntax to set the inputs and finish with
build(). - Project
Builder - Use builder syntax to set the inputs and finish with
build(). - Project
Cache - Project
Cache Builder - Use builder syntax to set the inputs and finish with
build(). - Project
Environment - Project
Environment Builder - Use builder syntax to set the inputs and finish with
build(). - Project
Source - Project
Source Builder - Use builder syntax to set the inputs and finish with
build(). - Retry
Build Request - Retry
Build Request Builder - Use builder syntax to set the inputs and finish with
build(). - Retry
Build Response - S3Logs
Config - S3Logs
Config Builder - Use builder syntax to set the inputs and finish with
build(). - Start
Build Request - Start
Build Request Builder - Use builder syntax to set the inputs and finish with
build(). - Start
Build Response - Stop
Build Request - Stop
Build Request Builder - Use builder syntax to set the inputs and finish with
build(). - Stop
Build Response - Tag
- TagBuilder
- Use builder syntax to set the inputs and finish with
build(). - Update
Project Request - Update
Project Request Builder - Use builder syntax to set the inputs and finish with
build(). - Update
Project Response - VpcConfig
- VpcConfig
Builder - Use builder syntax to set the inputs and finish with
build(). - Webhook
- Webhook
Builder - Use builder syntax to set the inputs and finish with
build(). - Webhook
Filter - Webhook
Filter Builder - Use builder syntax to set the inputs and finish with
build().