Structs
- AddPermission
Request - AddPermission
Request Builder - Use builder syntax to set the inputs and finish with
build(). - AddPermission
Response - Cors
- Cors
Builder - Use builder syntax to set the inputs and finish with
build(). - Create
Event Source Mapping Request - Request to create an event source mapping
- Create
Event Source Mapping Request Builder - Use builder syntax to set the inputs and finish with
build(). - Create
Function Request - Create
Function Request Builder - Use builder syntax to set the inputs and finish with
build(). - Create
Function UrlConfig Request - Create
Function UrlConfig Request Builder - Use builder syntax to set the inputs and finish with
build(). - Create
Function UrlConfig Response - Environment
- Environment
Builder - Use builder syntax to set the inputs and finish with
build(). - Ephemeral
Storage - Ephemeral
Storage Builder - Use builder syntax to set the inputs and finish with
build(). - Event
Source Mapping - Represents an event source mapping
- Filter
- Individual filter in filter criteria
- Filter
Builder - Use builder syntax to set the inputs and finish with
build(). - Filter
Criteria - Filter criteria for event source mapping
- Filter
Criteria Builder - Use builder syntax to set the inputs and finish with
build(). - Function
Code - Function
Code Builder - Use builder syntax to set the inputs and finish with
build(). - Function
Configuration - Function
UrlConfig - GetFunction
Response - GetPolicy
Response - Invoke
Request - Request for invoking a Lambda function
- Invoke
Request Builder - Use builder syntax to set the inputs and finish with
build(). - Invoke
Response - Response from invoking a Lambda function
- Lambda
Client - List
Event Source Mappings Request - Request to list event source mappings
- List
Event Source Mappings Request Builder - Use builder syntax to set the inputs and finish with
build(). - List
Event Source Mappings Response - Response from listing event source mappings
- Scaling
Config - Scaling configuration for SQS event source mapping
- Scaling
Config Builder - Use builder syntax to set the inputs and finish with
build(). - Tracing
Config - Tracing
Config Builder - Use builder syntax to set the inputs and finish with
build(). - Update
Event Source Mapping Request - Request to update an event source mapping
- Update
Event Source Mapping Request Builder - Use builder syntax to set the inputs and finish with
build(). - Update
Function Code Request - Update
Function Code Request Builder - Use builder syntax to set the inputs and finish with
build(). - Update
Function Configuration Request - Update
Function Configuration Request Builder - Use builder syntax to set the inputs and finish with
build(). - VpcConfig
- VPC configuration for Lambda function.
- VpcConfig
Builder - Use builder syntax to set the inputs and finish with
build().
Enums
- Invocation
Type - Lambda invocation type