pub struct EventSourceMapping {
pub uuid: Option<String>,
pub event_source_arn: Option<String>,
pub function_arn: Option<String>,
pub batch_size: Option<i32>,
pub last_modified: Option<f64>,
pub last_processing_result: Option<String>,
pub state: Option<String>,
pub state_transition_reason: Option<String>,
pub maximum_batching_window_in_seconds: Option<i32>,
pub function_response_types: Option<Vec<String>>,
pub filter_criteria: Option<FilterCriteria>,
pub scaling_config: Option<ScalingConfig>,
}Expand description
Represents an event source mapping
Fields
uuid: Option<String>The identifier of the event source mapping
event_source_arn: Option<String>The Amazon Resource Name (ARN) of the event source
function_arn: Option<String>The ARN of the Lambda function
batch_size: Option<i32>The maximum number of records in each batch that Lambda pulls from your queue and sends to your function
last_modified: Option<f64>The date that the event source mapping was last updated or that its state changed
last_processing_result: Option<String>The result of the last AWS Lambda invocation of your Lambda function
state: Option<String>The state of the event source mapping
state_transition_reason: Option<String>Indicates whether a user or Lambda made the last change to the event source mapping
maximum_batching_window_in_seconds: Option<i32>The maximum amount of time, in seconds, that Lambda spends gathering records before invoking the function
function_response_types: Option<Vec<String>>A list of current response type enums applied to the event source mapping
filter_criteria: Option<FilterCriteria>An object that defines the filter criteria that determine whether Lambda should process an event
scaling_config: Option<ScalingConfig>The maximum concurrency setting limits the number of concurrent instances of the function that an Amazon SQS event source can invoke